<?php
/**
 * Plugin Name: WordFex
 * Description: Sync new WordPress website's customers/users with Perfex CRM Leads, through Perfex's API.
 * Plugin URI: https://themesic.com
 * Author: Themesic Interactive
 * Author URI: https://themesic.com
 * Version: 1.0
 * License: GPLv2 or later
 */
 
// Add necessary actions
add_action('admin_menu', 'wordfex_add_admin_menu');
add_action('admin_init', 'wordfex_settings_init');

// Construct settings and fields
$settingfields = array('Perfex installation URL', 'Perfex API key', 'Leads Group ID');

function wordfex_add_admin_menu() {
    add_options_page('WordFex Settings', 'WordFex', 'manage_options', 'wordfex', 'wordfex_options_page');
};

function wordfex_settings_init() {
    global $settingfields;
    register_setting('wordfexpage', 'wordfex_settings');
    add_settings_section("wordfex_wordfexpage_section", __("WordFex Plugin Settings Page", "wordpress"), "wordfex_settings_section_callback", 'wordfexpage');
    foreach ($settingfields as $id => $item) {
        $i = 0;
        add_settings_field('wordfex_input_field_' . $id, __($item, "wordfex"), 'wordfex_input_render_field', "wordfexpage", "wordfex_wordfexpage_section", array('indicator' => $id));
        $i++;
    }
}

// Render fields
function wordfex_input_render_field($args) {
    $options = get_option('wordfex_settings');
    if (!isset($options['wordfex_input_field_2'])) {
        $options['wordfex_input_field_2'] = '1';
    }
    echo '<input type="text" value="' . htmlspecialchars($options['wordfex_input_field_' . $args['indicator']]) . '" name="wordfex_settings[wordfex_input_field_' . htmlspecialchars($args['indicator']) . ']">';
    echo '</input>';
};

// Inform user
function wordfex_settings_section_callback() {
    echo __('Enter your Perfex URL, your API key and your Leads Group ID below:', 'wordfex');
}

// Post data to options API of WordPress
function wordfex_options_page() {
?>
	<form action='options.php' method='post'>
	    
	<?php
    settings_fields('wordfexpage');
    do_settings_sections('wordfexpage');
    submit_button(); ?>

	</form>
	<?php
}


// Sync user with Perfex API, during a WordPress registration
add_action('user_register', 'sync_users');

function sync_users($user_id) {
    
    $ch = curl_init();
    
    $dir = plugin_dir_path(__FILE__);
    $options = get_option('wordfex_settings');
    $perfexurl = $options['wordfex_input_field_0'];
    if (substr($perfexurl, -1) == '/') {
        $perfexurl = substr($perfexurl, 0, -1);
    }
    $apikey = $options['wordfex_input_field_1'];
    $leadsgroup = $options['wordfex_input_field_2'];
    $posturl = $perfexurl . '/api/leads';
    //requirements curl
    $user_info = get_userdata($user_id);
    $username = $user_info->user_login;
    $first_name = $user_info->first_name;
    $last_name = $user_info->last_name;
    $leadname = $first_name . ' ' . $last_name;
    if ($leadname == ' ') {
        $leadname = $user_info->user_nicename;
    }
    $website = $user_info->user_url;
    $email = $user_info->user_email;
    $leadsgroup = $options['wordfex_input_field_2'];
    
    // Do the magic - execute cURL
    curl_setopt($ch, CURLOPT_URL, $posturl);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, "source=$leadsgroup&status=1&name=$leadname&website=$website&email=$email");
    $headers = array();
    $headers[] = 'Authtoken: ' . $apikey;
    $headers[] = 'Content-Type: application/x-www-form-urlencoded';
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    
    // Save result for logging purposes
    $result = curl_exec($ch);
    file_put_contents($dir . 'lastoutput.txt', $result);
    
    // Close cURL, free up system resources
    curl_close($ch);
}

?>